@@ -1,5 +1,4 @@
 from dataclasses import dataclass
-from dataclasses_json import dataclass_json, LetterCase
 from mlplatform_lib.dataclass import TableColumnInfo
 from typing import List
 
@@ -35,7 +34,6 @@ from typing import List
 # "numRows": 0
 
 
-@dataclass_json(letter_case=LetterCase.CAMEL)
 @dataclass
 class TableDescInfo:
     col_info_list: List[TableColumnInfo]
