@@ -9,6 +9,7 @@ from enum import Enum
 import json
 import requests
 from typing import Optional, Dict, List, Union, Tuple
+from mlplatform_lib.utils.dataclass_utils import from_dict
 
 
 HYPERDATA_DATETIME_FORMAT = "%Y.%m.%d %H.%M.%S"
@@ -144,7 +145,7 @@ class HyperdataHttpClient:
         result = self.send_request(
             "", {"dataobjects": do_id}, {"action": "Detail"}, {}, auth, HyperdataRequestType.READ,
         )
-        return DataObject.from_dict(result.data["dto"])
+        return from_dict(DataObject, result.data["dto"])
 
     #    def get_do_samples(self, auth: HyperdataUserAuth, dataobject_id: int, sample_size: int):
     #        return self.send_request(
@@ -186,7 +187,7 @@ class HyperdataHttpClient:
             auth,
             HyperdataRequestType.READ,
         )
-        return TableDescInfo.from_dict(result.data["dto"])
+        return from_dict(TableDescInfo, result.data["dto"])
 
     def download_do_to_csv(
         self, auth: HyperdataUserAuth, do_id: int
