@@ -5,7 +5,7 @@ from typing import Optional, Dict, List, Union
 from pathlib import Path
 from mlplatform_lib.dataclass.model import ModelInfoDto
 from datetime import datetime
-from mlplatform_lib.utils.dataclass_utils import from_dict
+from mlplatform_lib.utils.dataclass_utils import to_dict, from_dict
 
 
 MLPLATFORM_TIMSTAMP_FORMAT = "%Y-%m-%dT%H:%M:%S"
@@ -137,7 +137,7 @@ class MlPlatformHttpClient:
             "info",
             {"experiments": experiment_id, "trains": train_id, "models": model_id},
             {},
-            model_info.to_dict(),
+            to_dict(model_info),
             auth,
             MlPlatformRequestType.CREATE
         )
