@@ -21,5 +21,8 @@ def from_dict(dataclass, dict: Dict):
 
     instance = dataclass(**init_dict)
     for key, val in init_false_dict.items():
-        setattr(dataclass, key, val)
-    return instance
\ No newline at end of file
+        setattr(instance, key, val)
+    return instance
+
+def to_dict(instance):
+    return {inflection.camelize(key, False): val for key, val in instance.__dict__.items() }
\ No newline at end of file
